@@ -2,7 +2,7 @@ package Bio::MUST::Core::Taxonomy;
 # ABSTRACT: NCBI Taxonomy one-stop shop
 # CONTRIBUTOR: Loic MEUNIER <loic.meunier@doct.uliege.be>
 # CONTRIBUTOR: Mick VAN VLIERBERGHE <mvanvlierberghe@doct.uliege.be>
-$Bio::MUST::Core::Taxonomy::VERSION = '0.251140';
+$Bio::MUST::Core::Taxonomy::VERSION = '0.252040';
 use Moose;
 use namespace::autoclean;
 
@@ -192,28 +192,26 @@ sub _build_ncbi_tax {
 
         # allow most NCBI Taxonomy synonyms classes
         # cut -f4 -d'|' names.dmp | sort | uniq -c
-        # last updated on Aug-18-2021
-        #    1582   acronym
-        #  576856   authority
-        #     228   blast name
-        #   14555   common name
-        #   52040   equivalent name
-        #     484   genbank acronym
-        #   29979   genbank common name
-        #    1096   genbank synonym
-        #     733   in-part
-        #   61755   includes
-        # 2354398   scientific name
-        #  199012   synonym
-        #  167825   type material
+        # last updated on Jul-23-2025
+        #    2186     acronym
+        #  872668     authority
+        #     229     blast name
+        #   14861     common name
+        #   64495     equivalent name
+        #   30837     genbank common name
+        #     653     in-part
+        #   93973     includes
+        # 2686415     scientific name
+        #  354657     synonym
+        #  322156     type material
 
         synonyms => [
-            'synonym', 'genbank synonym',
-            'acronym', 'genbank acronym',
-            'anamorph', 'genbank anamorph', 'teleomorph',       # now useless
+            'acronym', 'synonym',
+          # 'genbank acronym', 'genbank synonym',               # now useless
+          # 'anamorph', 'genbank anamorph', 'teleomorph',       # now useless
             'blast name', 'common name', 'genbank common name',
             'equivalent name', 'includes',
-          # 'authority', 'in-part', 'type material',
+          # 'authority', 'in-part', 'type material',            # unwanted
         ]
     );
 }
@@ -351,11 +349,14 @@ sub _build_dupes_for {
 
 # Note: taken from nodes.dmp as follows (then manually re-ordered)
 # cut -f3 -d'|' nodes.dmp | sort | uniq
-# last updated on Aug-18-2021
+# last updated on Jul-23-2025
 const my @LEVELS => (
     'skip',                     # default collapsing level
     'top',                      # useful to preserve 'cellular organisms'
-    'superkingdom', 'kingdom', 'subkingdom',
+    'cellular root', 'acellular root',
+    'domain', 'realm',
+    'superkingdom',             # not in use anymore (kept for compatibility)
+    'kingdom', 'subkingdom',
     'superphylum', 'phylum', 'subphylum',
     'superclass', 'class', 'subclass', 'infraclass',
     'cohort', 'subcohort',
@@ -582,7 +583,7 @@ sub get_taxid_from_seq_id {
     }
 
     # 2. default path is to use already parsed taxon_id
-    # this applies to modern MUST SeqIds and taxonomy-aware abbr ids
+    # this applies to modern MUST SeqIds and taxonomy-aware abbr_ids
     return $seq_id->taxon_id
         if $seq_id->taxon_id;
 
@@ -778,6 +779,23 @@ sub get_taxa_from_taxid {                   ## no critic (RequireArgUnpacking)
 }
 
 
+# TODO: improve method using the following code snippet
+# TODO: allows for non-pretty (@) MUST ids in --auto-final-ids
+#     # fetch full taxonomy and lowest taxon
+#     my @taxonomy = $tax->get_taxonomy($taxon_id);
+#     my $org = $taxonomy[-1];
+#
+#     # proceed only if valid taxon_id
+#     if ($org) {
+#
+#         # build base MUST id...
+#         $must_id = SeqId->new_with(
+#             org         => $org,
+#             taxon_id    => $taxon_id,
+#             keep_strain => $ARGV_keep_strain,
+#         )->full_id;
+#
+
 sub get_nexus_label_from_seq_id {
     my $self   = shift;
     my $seq_id = shift;
@@ -1488,7 +1506,7 @@ sub _setup_ncbi_taxdir {
     ### Please be patient...
 
     # setup remote archive access
-    my $base = 'ftp://ftp.ncbi.nih.gov/pub/taxonomy';
+    my $base = 'https://ftp.ncbi.nih.gov/pub/taxonomy';
     my @targets = (
         'taxdump.tar.gz',
         $gi_mapper ? qw(gi_taxid_nucl.dmp.gz gi_taxid_prot.dmp.gz) : ()
@@ -1638,7 +1656,7 @@ sub _make_gca_files {
     my %node_for;
     my %fix_for;
 
-    my $base_acc = 'ftp://ftp.ncbi.nlm.nih.gov/genomes/ASSEMBLY_REPORTS';
+    my $base_acc = 'https://ftp.ncbi.nlm.nih.gov/genomes/ASSEMBLY_REPORTS';
 
     for my $target (@targets_acc) {
         #### $target
@@ -1678,6 +1696,7 @@ sub _make_gca_files {
             # skip GCF entries with corresponding GCA already available...
             # ... and transform remaining GCF entries into GCA entries
             # Note: versions are considered relevant; only prefix is ignored
+
             if ($accession =~ $GCAONLY) {
                 $accession =~ tr/F/A/;
                 next LINE if defined $name_for{$accession};
@@ -1833,7 +1852,7 @@ sub _setup_gtdb_taxdir {
     ### Please be patient...
 
     # setup remote archive access
-    my $base = 'https://data.gtdb.ecogenomic.org/releases/latest';
+    my $base = 'https://data.ace.uq.edu.au/public/gtdb/data/releases/latest/';
 
     # get directory listing of latest GTDB release
     my $listing = get($base)
@@ -1900,8 +1919,8 @@ sub _setup_gtdb_taxdir {
 
     # hash for rank code
     my %rank_for = map {
-       $_ eq 'superkingdom' ? 'd__' : substr($_, 0, 1) . '__' => $_
-    } qw (superkingdom phylum class order family genus species);
+        substr($_, 0, 1) . '__' => $_
+    } qw (domain phylum class order family genus species);
 
     # setup taxonomic tree
     my %tree = (
@@ -1920,7 +1939,10 @@ sub _setup_gtdb_taxdir {
     );
 
     # fill up taxonomic tree
-    for my $gca ( keys %{$table_for} ) {
+    my %seen;
+
+    LINE:
+    for my $gca (keys %{$table_for}) {
 
         # get GTDB taxonomy
         my $lineage = $table_for->{$gca}{'gtdb_taxonomy'};
@@ -1953,16 +1975,15 @@ sub _setup_gtdb_taxdir {
             $tree_ref->{$taxon_id}{uniq_name} = $uniq_name
                 if $uniq_name;
 
-            # store GCA|F
+            # skip GCF entries with corresponding GCA already available...
+            # ... and transform remaining GCF entries into GCA entries
+            # Note: input order is actually irrelevant (no need to sort keys)
+            # Note: versions are considered relevant; only prefix is ignored
             if ($rank eq 'species') {
-
-                # change GCF to GCA and store it
-                if ($gca =~ m/^GCF/xms) {
-                    my $new_gca = $gca =~ tr/F/A/r;
-                    push @{ $tree_ref->{$taxon_id}{gca} }, $new_gca;
-                }
-
+                $gca =~ tr/F/A/;
+                next LINE if $seen{$gca};
                 push @{ $tree_ref->{$taxon_id}{gca} }, $gca;
+                $seen{$gca} = 1;
             }
 
             # setup children entry if lineage not yet exhausted
@@ -1993,6 +2014,8 @@ sub _setup_gtdb_taxdir {
     _write_dmp_files( $name_out, $node_out, $gcaname_out, $gcanode_out,
         1, 1, $tree{1} );
 
+    # TODO: make this part more similar with NCBI (error and cache handling)
+
     if ( -r $name_file && -r $node_file ) {
         ### Successfully wrote taxid files!
     }
@@ -2086,6 +2109,17 @@ sub _append2dmp {                           ## no critic (ProhibitManyArgs)
     return;
 }
 
+sub no_warnings {
+    my $class = shift;
+
+    return sub {
+        my $msg = shift;
+        return if $msg =~ m/is\ taxonomically\ ambiguous/xms;
+        return if $msg =~ m/cannot\ fetch\ tax/xms;
+        warn $msg;              ## no critic (ErrorHandling::RequireCarping)
+    };
+}
+
 no Moose::Util::TypeConstraints;
 
 __PACKAGE__->meta->make_immutable;
@@ -2101,7 +2135,7 @@ Bio::MUST::Core::Taxonomy - NCBI Taxonomy one-stop shop
 
 =head1 VERSION
 
-version 0.251140
+version 0.252040
 
 =head1 SYNOPSIS
 
